@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: actions.c,v 1.197 2003/05/05 22:15:00 f1rmb Exp $
+ * $Id: actions.c,v 1.208 2003/07/25 22:52:57 f1rmb Exp $
  *
  * implementation of all the various actions for the gui (play, stop, open, pause...)
  *
@@ -95,11 +95,15 @@ void gui_display_logo(void) {
   if(gGui->visual_anim.running)
     visual_anim_stop();
 
-  (void) gui_xine_open_and_play((char *)gGui->logo_mrl, NULL, 0, 0, 0);
+  if(gGui->display_logo)
+    (void) gui_xine_open_and_play((char *)gGui->logo_mrl, NULL, 0, 0, 0);
+
   gGui->logo_mode = 1;
+  
   panel_reset_slider();
   if(stream_infos_is_visible())
     stream_infos_update_infos();
+  
 }
 
 static int _gui_xine_play(xine_stream_t *stream, 
@@ -115,7 +119,7 @@ static int _gui_xine_play(xine_stream_t *stream,
   
   if(start_time_in_secs)
     start_time_in_secs *= 1000;
-      
+  
   has_video = xine_get_stream_info(stream, XINE_STREAM_INFO_HAS_VIDEO);
   if (has_video)
     has_video = !xine_get_stream_info(stream, XINE_STREAM_INFO_IGNORE_VIDEO);
@@ -132,12 +136,7 @@ static int _gui_xine_play(xine_stream_t *stream,
       gGui->visual_anim.running = 1;
 
   }
-  else if(has_video && gGui->post_video && (gGui->post_video_num > 0)) {
 
-    (void) post_rewire_video_post_to_stream(stream);
-
-  }
-  
   if((ret = xine_play(stream, start_pos, start_time_in_secs)) == 0) {
     gui_handle_xine_error(stream, NULL);
   }
@@ -521,9 +520,12 @@ void gui_exit (xitk_widget_t *w, void *data) {
 
 #ifdef HAVE_LIRC
   if(gGui->lirc_enable)
-    deinit_lirc();
+    lirc_stop();
 #endif
-
+  
+  if(gGui->stdctl_enable) 
+    stdctl_stop();
+  
   xitk_stop();
   /* 
    * This prevent xine waiting till the end of time for an
@@ -647,7 +649,7 @@ void gui_eject(xitk_widget_t *w, void *data) {
 	      mmk = (mediamark_t **) xine_xmalloc(sizeof(mediamark_t *) * 2);
 	    else { 
 	      if(new_num > 1) {
-		mmk = (mediamark_t **) realloc(mmk, sizeof(mediamark_t *) * (new_num + 1));
+		mmk = (mediamark_t **) realloc(mmk, sizeof(mediamark_t *) * (new_num + 2));
 	      }
 	    }
 	    
@@ -746,28 +748,36 @@ static void set_fullscreen_mode(int fullscreen_mode) {
   int kbedit       = kbedit_is_visible();
   int event_sender = event_sender_is_visible();
   int stream_infos = stream_infos_is_visible();
+  int tvset        = tvset_is_visible();
+  int pplugin      = pplugin_is_visible();
+
+  if(!(video_window_is_visible()))
+    return;
 
   if(panel)
     panel_toggle_visibility(NULL, NULL);
-  if(mrl_browser)
-    mrl_browser_toggle_visibility(NULL, NULL);
-  if(playlist)
-    playlist_toggle_visibility(NULL, NULL);
-  if(control)
-    control_toggle_visibility(NULL, NULL);
-  if(setup)
-    setup_toggle_visibility(NULL, NULL);
-  if(viewlog)
-    viewlog_toggle_visibility(NULL, NULL);
-  if(kbedit)
-    kbedit_toggle_visibility(NULL, NULL);
-  if(event_sender)
-    event_sender_toggle_visibility(NULL, NULL);
-  if(stream_infos)
-    stream_infos_toggle_visibility(NULL, NULL);
-  
-  if(!(video_window_is_visible()))
-    video_window_set_visibility(1);
+  else {
+    if(mrl_browser)
+      mrl_browser_toggle_visibility(NULL, NULL);
+    if(playlist)
+      playlist_toggle_visibility(NULL, NULL);
+    if(control)
+      control_toggle_visibility(NULL, NULL);
+    if(setup)
+      setup_toggle_visibility(NULL, NULL);
+    if(viewlog)
+      viewlog_toggle_visibility(NULL, NULL);
+    if(kbedit)
+      kbedit_toggle_visibility(NULL, NULL);
+    if(event_sender)
+      event_sender_toggle_visibility(NULL, NULL);
+    if(stream_infos)
+      stream_infos_toggle_visibility(NULL, NULL);
+    if(tvset)
+      tvset_toggle_visibility(NULL, NULL);
+    if(pplugin)
+      pplugin_toggle_visibility(NULL, NULL);
+  }
   
   video_window_set_fullscreen_mode(fullscreen_mode);
   
@@ -777,22 +787,30 @@ static void set_fullscreen_mode(int fullscreen_mode) {
   
   if(panel)
     panel_toggle_visibility(NULL, NULL);
-  if(mrl_browser)
-    mrl_browser_toggle_visibility(NULL, NULL);
-  if(playlist)
-    playlist_toggle_visibility(NULL, NULL);
-  if(control)
-    control_toggle_visibility(NULL, NULL);
-  if(setup)
-    setup_toggle_visibility(NULL, NULL);
-  if(viewlog)
-    viewlog_toggle_visibility(NULL, NULL);
-  if(kbedit)
-    kbedit_toggle_visibility(NULL, NULL);
-  if(event_sender)
-    event_sender_toggle_visibility(NULL, NULL);
-  if(stream_infos)
-    stream_infos_toggle_visibility(NULL, NULL);
+  else {
+    if(mrl_browser)
+      mrl_browser_toggle_visibility(NULL, NULL);
+    if(playlist)
+      playlist_toggle_visibility(NULL, NULL);
+    if(control)
+      control_toggle_visibility(NULL, NULL);
+    if(setup)
+      setup_toggle_visibility(NULL, NULL);
+    if(viewlog)
+      viewlog_toggle_visibility(NULL, NULL);
+    if(kbedit)
+      kbedit_toggle_visibility(NULL, NULL);
+    if(event_sender)
+      event_sender_toggle_visibility(NULL, NULL);
+    if(stream_infos)
+      stream_infos_toggle_visibility(NULL, NULL);
+    if(tvset)
+      tvset_toggle_visibility(NULL, NULL);
+    if(pplugin) {
+      pplugin_toggle_visibility(NULL, NULL);
+    }
+  }
+
 }
 
 void gui_set_fullscreen_mode(xitk_widget_t *w, void *data) {
@@ -1411,6 +1429,46 @@ void gui_stream_infos_show(xitk_widget_t *w, void *data) {
   }
 }
 
+void gui_tvset_show(xitk_widget_t *w, void *data) {
+  
+  if (tvset_is_running() && !tvset_is_visible())
+    tvset_toggle_visibility(NULL, NULL);
+  else if(!tvset_is_running())
+    tvset_panel();
+  else {
+    if(gGui->use_root_window)
+      tvset_toggle_visibility(NULL, NULL);
+    else
+      tvset_end();
+  }
+}
+
+void gui_vpp_show(xitk_widget_t *w, void *data) {
+  
+  if (pplugin_is_running() && !pplugin_is_visible())
+    pplugin_toggle_visibility(NULL, NULL);
+  else if(!pplugin_is_running())
+    pplugin_panel();
+  else {
+    if(gGui->use_root_window)
+      pplugin_toggle_visibility(NULL, NULL);
+    else
+      pplugin_end();
+  }
+}
+
+void gui_vpp_enable(void) {
+  if(pplugin_is_post_selected()) {
+    gGui->post_enable = !gGui->post_enable;
+    osd_display_info(_("Post plugins: %s."), (gGui->post_enable) ? _("enabled") : _("disabled"));
+    pplugin_update_enable_button();
+    if(pplugin_is_visible())
+      pplugin_rewire_from_posts_window();
+    else
+      pplugin_rewire_posts();
+  }
+}
+
 void gui_viewlog_show(xitk_widget_t *w, void *data) {
 
   if (viewlog_is_running() && !viewlog_is_visible())
@@ -1590,18 +1648,22 @@ void gui_add_mediamark(void) {
     if(gui_xine_get_pos_length(gGui->stream, NULL, &secs, NULL)) {
       secs /= 1000;
       
-      mediamark_add_entry(gGui->mmk.mrl, gGui->mmk.ident, gGui->mmk.sub, secs, -1, gGui->mmk.offset);
+      mediamark_add_entry(gGui->mmk.mrl, gGui->mmk.ident, 
+			  gGui->mmk.sub, secs, -1, gGui->mmk.offset);
+      playlist_update_playlist();
     }
   }
 }
 
 static void fileselector_cancel_callback(filebrowser_t *fb) {
   sprintf(gGui->curdir, "%s", (filebrowser_get_current_dir(fb)));
+  config_update_string("input.file_origin_path", gGui->curdir);
 }
 static void fileselector_callback(filebrowser_t *fb) {
   char *file;
 
   sprintf(gGui->curdir, "%s", (filebrowser_get_current_dir(fb)));
+  config_update_string("input.file_origin_path", gGui->curdir);
 
   if((file = filebrowser_get_full_filename(fb)) != NULL) {
     int first = gGui->playlist.num;
@@ -1626,6 +1688,7 @@ static void fileselector_all_callback(filebrowser_t *fb) {
   char  *path;
 
   sprintf(gGui->curdir, "%s", (filebrowser_get_current_dir(fb)));
+  config_update_string("input.file_origin_path", gGui->curdir);
 
   if((files = filebrowser_get_all_files(fb)) != NULL) {
     int i = 0;
