@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: lirc.h,v 1.5 2003/01/05 00:24:34 f1rmb Exp $
+ * $Id: lirc.h,v 1.7 2003/07/22 21:33:08 f1rmb Exp $
  *
  * lirc specific stuff
  *
@@ -32,23 +32,8 @@
 
 #ifdef HAVE_LIRC
 
-/*
- * Initialize lirc support
- */
-
-void init_lirc(void);
-
-/*
- * De-init lirc support
- */
-
-void deinit_lirc(void);
-
-/*
- * Lirc thread loop
- */
-
-void *xine_lirc_loop(void *dummy);
+void lirc_start(void);
+void lirc_stop(void);
 
 #endif
 
