@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: playlist.c,v 1.125 2003/05/05 22:15:02 f1rmb Exp $
+ * $Id: playlist.c,v 1.126 2003/07/14 22:44:09 f1rmb Exp $
  *
  * Playlist Editor
  *
@@ -641,9 +641,9 @@ void playlist_update_playlist(void) {
  * Leaving playlist editor
  */
 void playlist_exit(xitk_widget_t *w, void *data) {
-  window_info_t wi;
 
   if(playlist) {
+    window_info_t wi;
     
     mmk_editor_end();
 
@@ -724,7 +724,7 @@ void playlist_scan_input(xitk_widget_t *w, void *ip) {
     while(autoplay_plugins[i] != NULL) {
       
       if(!strcasecmp(autoplay_plugins[i], xitk_labelbutton_get_label(w))) {
-	int                num_mrls;
+	int                num_mrls = 0;
 	char             **autoplay_mrls = 
 	  xine_get_autoplay_mrls (gGui->xine, autoplay_plugins[i], &num_mrls);
 	
