@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: image.c,v 1.49 2003/02/11 00:59:09 f1rmb Exp $
+ * $Id: image.c,v 1.51 2003/07/18 21:34:40 f1rmb Exp $
  *
  */
 #ifdef HAVE_CONFIG_H
@@ -151,6 +151,7 @@ static void xitk_image_xitk_pixmap_destroyer(xitk_pixmap_t *xpix) {
 
   if(xpix->shm) {
     shmdt(xpix->shminfo->shmaddr);
+    shmctl(xpix->shminfo->shmid, IPC_RMID, 0);
     free(xpix->shminfo);
   }
 #endif
@@ -493,7 +494,7 @@ xitk_image_t *xitk_image_create_image_with_colors_from_string(ImlibData *im,
 	x = (width - length);
       
       XLOCK(im->x.disp);
-      XDrawString(im->x.disp, image->image->pixmap, gc, 
+      xitk_font_draw_string(fs, image->image->pixmap, gc, 
 		  x, (j - descent), lines[i], strlen(lines[i]));
       XUNLOCK(im->x.disp);
 	
@@ -1157,7 +1158,7 @@ static void _draw_frame(ImlibData *im, xitk_pixmap_t *p,
   if(title) {
     XLOCK(im->x.disp);
     XSetForeground(im->x.disp, p->gc, xitk_get_pixel_color_black(im));
-    XDrawString(im->x.disp, p->pixmap, p->gc, (x + 6), y, buf, strlen(buf));
+    xitk_font_draw_string(fs, p->pixmap, p->gc, (x + 6), y, buf, strlen(buf));
     XUNLOCK(im->x.disp);
     
     xitk_font_unload_font(fs);
@@ -1557,9 +1558,9 @@ static xitk_widget_t *_xitk_image_create (xitk_widget_list_t *wl,
 
   mywidget->wl                    = wl;
 
-  mywidget->enable                = 1;
+  mywidget->enable                = 0;
   mywidget->running               = 1;
-  mywidget->visible               = 1;
+  mywidget->visible               = 0;
   mywidget->have_focus            = FOCUS_LOST;
   mywidget->imlibdata             = private_data->imlibdata;
   mywidget->x                     = x;
