@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: label.c,v 1.55 2003/03/28 13:56:32 f1rmb Exp $
+ * $Id: label.c,v 1.57 2003/07/18 21:34:40 f1rmb Exp $
  *
  */
 #ifdef HAVE_CONFIG_H
@@ -111,6 +111,7 @@ static void notify_destroy(xitk_widget_t *w) {
       private_data->labelpix = NULL;
     }
     
+    XITK_FREE(private_data->label);
     XITK_FREE(private_data->fontname);
     XITK_FREE(private_data->skin_element_name);
 
@@ -187,7 +188,7 @@ static void paint_label(xitk_widget_t *w) {
 		 0, 0, private_data->font->width, private_data->font->height, 0, 0);
       XSetForeground(private_data->imlibdata->x.disp, font->image->gc, 
 		     xitk_get_pixel_color_black(private_data->imlibdata));
-      XDrawString(private_data->imlibdata->x.disp, bg->image->pixmap, font->image->gc,
+      xitk_font_draw_string(fs, bg->image->pixmap, font->image->gc,
 		  2, ((private_data->font->height + asc + des)>>1) - des,
 		  private_data->label, strlen(private_data->label));
       XCopyArea (private_data->imlibdata->x.disp, bg->image->pixmap, w->wl->win, 
@@ -557,5 +558,5 @@ xitk_widget_t *xitk_noskin_label_create(xitk_widget_list_t *wl,
 					int x, int y, int width, int height, char *fontname) {
   XITK_CHECK_CONSTITENCY(l);
 
-  return _xitk_label_create(wl, NULL, l, x, y, width, height, NULL, fontname, 1, 1);
+  return _xitk_label_create(wl, NULL, l, x, y, width, height, NULL, fontname, 0, 0);
 }
