@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: window.c,v 1.35 2003/04/27 00:18:52 f1rmb Exp $
+ * $Id: window.c,v 1.37 2003/07/18 21:34:40 f1rmb Exp $
  *
  */
 #ifdef HAVE_CONFIG_H
@@ -424,7 +424,7 @@ xitk_window_t *xitk_window_create_dialog_window(ImlibData *im, char *title,
   else
     XSetForeground(im->x.disp, bar->gc, (xitk_get_pixel_color_from_rgb(im, 85, 12, 135)));
   
-  XDrawString(im->x.disp, bar->pixmap, bar->gc, 
+  xitk_font_draw_string(fs, bar->pixmap, bar->gc, 
 	      (width - wid) - TITLE_BAR_HEIGHT, ((TITLE_BAR_HEIGHT+asc+des) >> 1) - des, 
 	      title, strlen(title));
   XUNLOCK(im->x.disp);
@@ -932,6 +932,8 @@ xitk_window_t *xitk_window_dialog_one_button_with_width(ImlibData *im, char *tit
 					wd->widget_list,
 					(void *)wd);
 
+  xitk_enable_and_show_widget(wd->wyes);
+
   return wd->xwin;
 }
 
@@ -1124,6 +1126,9 @@ xitk_window_t *xitk_window_dialog_two_buttons_with_width(ImlibData *im, char *ti
 					NULL,
 					wd->widget_list,
 					(void *)wd);
+  xitk_enable_and_show_widget(wd->wyes);
+  xitk_enable_and_show_widget(wd->wno);
+
   return wd->xwin;
 }
 
@@ -1342,6 +1347,9 @@ xitk_window_t *xitk_window_dialog_three_buttons_with_width(ImlibData *im, char *
 					NULL,
 					wd->widget_list,
 					(void *)wd);
+  xitk_enable_and_show_widget(wd->wyes);
+  xitk_enable_and_show_widget(wd->wno);
+  xitk_enable_and_show_widget(wd->wcancel);
 
   return wd->xwin;
 }
