@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: xitk.c,v 1.101 2003/05/13 23:03:30 f1rmb Exp $
+ * $Id: xitk.c,v 1.105 2003/07/18 21:34:40 f1rmb Exp $
  *
  */
 #define _XITK_C_
@@ -134,6 +134,7 @@ static __xitk_t    *gXitk;
 static pid_t        xitk_pid;
 static Atom XA_WIN_LAYER = None, XA_STAYS_ON_TOP = None;
 static Atom XA_NET_WM_STATE = None, XA_NET_WM_STATE_ABOVE = None;
+static Atom XA_NET_WM_STATE_FULLSCREEN = None;
 
 
 void widget_stop(void);
@@ -503,6 +504,7 @@ static uint32_t xitk_check_wm(Display *display) {
 	   (format_return == 32) && (nitems_return == 1) && (bytes_after_return == 0)) {
 	  
 	  if(win_id == *(long *)prop_return) {
+	    if (wm_name) free(wm_name);
 	    wm_name = get_wm_name(display, win_id, "_NET_WM_NAME");
 	    type |= WM_TYPE_EWMH_COMP;
 	  }
@@ -520,6 +522,7 @@ static uint32_t xitk_check_wm(Display *display) {
     XA_STAYS_ON_TOP       = XInternAtom(display, "_NET_WM_STATE_STAYS_ON_TOP", False);
     XA_NET_WM_STATE       = XInternAtom(display, "_NET_WM_STATE", False);
     XA_NET_WM_STATE_ABOVE = XInternAtom(display, "_NET_WM_STATE_ABOVE", False);
+    XA_NET_WM_STATE_FULLSCREEN = XInternAtom(display, "_NET_WM_STATE_FULLSCREEN", False);
   }
   
   switch(type & WM_TYPE_COMP_MASK) {
@@ -626,13 +629,13 @@ int xitk_get_layer_level(void) {
   case WM_TYPE_ICE:
   case WM_TYPE_AFTERSTEP:
   case WM_TYPE_BLACKBOX:
+  case WM_TYPE_WINDOWMAKER:
     level = 10; /* Wrong, but we need to provide a default value */
     break;
   case WM_TYPE_XFCE:
     level = 8;
     break;
   case WM_TYPE_E:
-  case WM_TYPE_WINDOWMAKER:
     level = 6;
     break;
   case WM_TYPE_MOTIF:
@@ -764,6 +767,31 @@ void xitk_set_window_layer(Window window, int layer) {
   XUnlockDisplay(gXitk->display);
 }
 
+void xitk_set_ewmh_fullscreen(Window window) {
+  XEvent xev;
+  
+  if(!(gXitk->wm_type & WM_TYPE_EWMH_COMP) || (window == None))
+    return;
+  
+  XLockDisplay(gXitk->display);
+  
+  xev.xclient.type         = ClientMessage;
+  xev.xclient.send_event   = True;
+  xev.xclient.display      = gXitk->display;
+  xev.xclient.window       = window;
+  xev.xclient.message_type = XA_NET_WM_STATE;
+  xev.xclient.format       = 32;
+  xev.xclient.data.l[0]    = (long) 1;
+  xev.xclient.data.l[1]    = (long) XA_NET_WM_STATE_FULLSCREEN;
+  xev.xclient.data.l[2]    = (long) None;
+  
+  XSendEvent(gXitk->display, DefaultRootWindow(gXitk->display), 
+	     False, SubstructureRedirectMask | SubstructureNotifyMask, (XEvent*) &xev);
+  
+  XUnlockDisplay(gXitk->display);
+
+}
+
 /*
  * Create a new widget_list, store the pointer in private
  * list of xitk_widget_list_t, then return the widget_list pointer.
@@ -952,6 +980,7 @@ void xitk_unregister_event_handler(xitk_register_key_t *key) {
 	free(fx->xdnd);
       }
 
+      fx->xevent_callback = NULL;
       xitk_list_delete_current(gXitk->gfx); 
       free(fx);
       
@@ -1470,7 +1499,11 @@ void xitk_xevent_notify(XEvent *event) {
  */
 void xitk_init(Display *display) {
   
-  printf("-[ xiTK version %d.%d.%d ]-\n",
+  printf("-[ xiTK version %d.%d.%d "
+#ifdef WITH_XMB
+	 "[XMB]"
+#endif
+	 "]-\n",
 	 XITK_MAJOR_VERSION, XITK_MINOR_VERSION, XITK_SUB_VERSION);
 
   xitk_pid = getppid();
@@ -1550,6 +1583,9 @@ void xitk_init(Display *display) {
 #endif
 
   gXitk->wm_type = xitk_check_wm(display);
+  
+  /* init font caching */
+  xitk_font_cache_init();
 }
 
 /* Return True is event type isn't completion */
@@ -1691,6 +1727,9 @@ void xitk_run(xitk_startup_callback_t cb, void *data) {
   xitk_config_deinit(gXitk->config);
   
   XITK_FREE(gXitk);
+
+  /* destroy font caching */
+  xitk_font_cache_done();
 }
 
 /*
@@ -1810,35 +1849,31 @@ char *xitk_set_locale(void) {
  * Return home directory.
  */
 const char *xitk_get_homedir(void) {
-  struct passwd *pw = NULL;
-  char *homedir = NULL;
-#ifdef HAVE_GETPWUID_R
-  int ret;
-  struct passwd pwd;
-  char *buffer = NULL;
-  int bufsize = 256;
+  struct passwd  pwd, *pw = NULL;
+  static char    homedir[BUFSIZ] = {0,};
 
-  buffer = (char *) xitk_xmalloc(bufsize);
-  
-  if((ret = getpwuid_r(getuid(), &pwd, buffer, bufsize, &pw)) != 0) {
+  if(homedir[0])
+    return homedir;
+
+#ifdef HAVE_GETPWUID_R
+  if(getpwuid_r(getuid(), &pwd, homedir, sizeof(homedir), &pw) != 0 || pw == NULL) {
 #else
   if((pw = getpwuid(getuid())) == NULL) {
 #endif
-    if((homedir = getenv("HOME")) == NULL) {
-      XITK_WARNING("Unable to get home directory, set it to /tmp.\n");
-      homedir = strdup("/tmp");
+    char *tmp = getenv("HOME");
+    if(tmp) {
+      strncpy(homedir, tmp, sizeof(homedir));
+      homedir[sizeof(homedir) - 1] = '\0';
     }
+  } else {
+    strncpy(homedir, pw->pw_dir, sizeof(homedir));
+    homedir[sizeof(homedir) - 1] = '\0';
   }
-  else {
-    if(pw) 
-      homedir = strdup(pw->pw_dir);
+
+  if(!homedir[0]) {
+    XITK_WARNING("Unable to get home directory, set it to /tmp.\n");
+    strcpy(homedir, "/tmp");
   }
-  
-  
-#ifdef HAVE_GETPWUID_R
-  if(buffer) 
-    XITK_FREE(buffer);
-#endif
-  
+
   return homedir;
 }
